@@ -1,20 +1,20 @@
 #' QTL search by IM
 #'
 #' Expectation-maximization algorithm for QTL interval mapping to search
-#' the possible position of QTL in all chromosome.
+#' the possible position of QTL in all chromosomes.
 #'
 #' @param marker matrix. A k*2 matrix contains the marker information,
 #' where the row dimension k is the number of markers in the chromosomes.
 #' The first column labels the chromosomes where the markers are located,
 #' and the second column labels the positions of QTLs (in morgan (M) or
-#' centimorgan (cM)). Note that chromosome and position must be divided
+#' centimorgan (cM)). Note that chromosomes and positions must be divided
 #' in order.
 #' @param geno matrix. A n*k matrix contains the k markers of the n
 #' individuals. The marker genotypes of P1 homozygote (MM),
-#' heterozygote (Mm) and P2 homozygote (mm) are coded as 2, 1 and 0,
+#' heterozygote (Mm), and P2 homozygote (mm) are coded as 2, 1, and 0,
 #' respectively, and NA for missing value.
-#' @param y vector. A vector with n elements that contains the phenotype
-#' values of individuals.
+#' @param y vector. A vector with n elements contains the phenotype values
+#' of individuals.
 #' @param method character. method="EM" means the interval mapping method
 #' by Lander and Botstein (1989) is used in the analysis, while
 #' method="REG" means  the approximate regression interval mapping method
@@ -23,28 +23,29 @@
 #' backcross (type="BC"), advanced intercross population (type="AI"), and
 #' recombinant inbred population (type="RI").
 #' @param D.matrix matrix. The design matrix of the IM model. If
-#' D.matrix=NULL, the design matrix will be the constructed using the
-#' Cockerham’s model. In BC population, it is a 2*1 matrix which is
-#' 0.5, -0.5 for additive effect. In RI or AI population, it is a 3*2 matrix
-#' whose first column is 1, 0, -1 for additive effect and second column is
-#' 0.5, -0.5, 0.5 for dominant effect.
+#' D.matrix=NULL, the design matrix will be constructed using the Cockerham’s
+#' model. In BC population, it is a 2*1 matrix which is 0.5, -0.5 for
+#' additive effect. In RI or AI population, it is a 3*2 matrix whose first
+#' column is 1, 0, -1 for additive effect and the second column is 0.5, -0.5,
+#' 0.5 for dominant effect.
 #' @param ng integer. The generation number of the population type. For
 #' example, the BC1 population is type="BC" with ng=1; the AI F3
 #' population is type="AI" with ng=3.
 #' @param cM logical. Specify the unit of marker position. cM=TRUE for
-#' centi-Morgan. Or cM=FALSE for Morgan.
+#' centimorgan. Or cM=FALSE for morgan.
 #' @param speed numeric. The walking speed of the QTL search (in cM).
 #' @param crit numeric. The convergent criterion of EM algorithm.
 #' The E and M steps will be iterated until a convergent criterion
-#' is satisfied.
+#' is satisfied. It must be between 0 and 1.
 #' @param d.eff logical. Specify whether the dominant effect will be
 #' considered in the parameter estimation or not for AI or RI population.
 #' @param LRT.thre logical or numeric. If being TRUE, the LRT threshold
 #' will be computed based on the Gaussian stochastic process
 #' (Kao and Ho 2012). Or users can input a numerical value as the LRT
-#' threshold to assessing the significance of QTL detection.
+#' threshold to assess the significance of QTL detection.
 #' @param simu integer. To decide how many simulation samples will be used
-#' to compute the LRT threshold using the Gaussian process.
+#' to compute the LRT threshold using the Gaussian process. It must be
+#' between 50 and 10^8.
 #' @param alpha numeric. The type I error rate for the LRT threshold.
 #' @param detect logical. Whether the significant QTL whose LRT statistic
 #' is larger than the LRT threshold will be shown in the output dataset or
@@ -55,15 +56,15 @@
 #' statistics for the genome in one figure.
 #' @param plot.chr logical. If being TRUE, output the profile of LRT
 #' statistics for the chromosomes.
-#' @param console logical. To decide whether the process of algorithm will
+#' @param console logical. To decide whether the process of the algorithm will
 #' be shown in the R console or not.
 #'
 #' @return
 #' \item{effect}{The estimated effects and LRT statistics of all positions.}
-#' \item{LRT.threshold}{The LRT threshold value computed for the data using the
-#' Gaussian stochastic process (Kuo 2011; Kao and Ho 2012).}
-#' \item{detect.QTL}{The positions, effects and LRT statistics of the detected
-#' QTL significant using the obtained LRT threshold value.}
+#' \item{LRT.threshold}{The LRT threshold value is computed for the data using
+#' the Gaussian stochastic process (Kuo 2011; Kao and Ho 2012).}
+#' \item{detect.QTL}{The positions, effects, and LRT statistics of the detected
+#' QTL are significant using the obtained LRT threshold value.}
 #'
 #' Graphical outputs including LOD value and effect of each position.
 #'
@@ -154,8 +155,8 @@ IM.search <- function(marker, geno, y, method = "EM", type = "RI", D.matrix = NU
     stop("Parameter speed error, please input a positive number.", call. = FALSE)
   }
 
-  if(!is.numeric(crit) | length(crit) > 1 | min(crit) < 0){
-    stop("Parameter crit error, please input a positive number.", call. = FALSE)
+  if(!is.numeric(crit) | length(crit) > 1 | min(crit) <= 0 | max(crit) >= 1){
+    stop("Parameter crit error, please input a positive number between 0 and 1.", call. = FALSE)
   }
 
   if(!d.eff[1] %in% c(0,1) | length(d.eff) > 1){d.eff <- TRUE}
@@ -166,7 +167,7 @@ IM.search <- function(marker, geno, y, method = "EM", type = "RI", D.matrix = NU
     simu = 1000
   }
 
-  if(!is.numeric(alpha) | length(alpha) > 1 | min(alpha) < 0 | max(alpha) > 1){
+  if(!is.numeric(alpha) | length(alpha) > 1 | min(alpha) <= 0 | max(alpha) >= 1){
     stop("Parameter alpha error, please input a positive number between 0 and 1.", call. = FALSE)
   }
 
