@@ -8,22 +8,22 @@
 #' the row dimension q is the number of QTLs in the chromosomes. The
 #' first column labels the chromosomes where the QTLs are located, and
 #' the second column labels the positions of QTLs (in morgan (M) or
-#' centimorgan (cM)). Note that chromosome and position must be divided
+#' centimorgan (cM)). Note that chromosomes and positions must be divided
 #' in order.
 #' @param marker matrix. A k*2 matrix contains the marker information,
 #' where the row dimension k is the number of markers in the chromosomes.
 #' The first column labels the chromosomes where the markers are located,
 #' and the second column labels the positions of QTLs (in morgan (M) or
-#' centimorgan (cM)). Note that chromosome and position must be divided
+#' centimorgan (cM)). Note that chromosomes and positions must be divided
 #' in order.
 #' @param geno matrix. A n*k matrix contains the k markers of the n
 #' individuals. The marker genotypes of P1 homozygote (MM),
-#' heterozygote (Mm) and P2 homozygote (mm) are coded as 2, 1 and 0,
+#' heterozygote (Mm), and P2 homozygote (mm) are coded as 2, 1, and 0,
 #' respectively, and NA for missing value.
-#' @param y vector. An vector that contains the phenotype values of
-#' individuals with genotyped.
-#' @param yu vector. An vector that contains the phenotype value
-#' of the individuals without genotyped.
+#' @param y vector. A vector that contains the phenotype values of
+#' individuals with genotypes.
+#' @param yu vector. A vector that contains the phenotype value
+#' of the individuals without genotypes.
 #' @param sele.g character. If sele.g="n", it will consider that the
 #' data is not a selective genotyping data but the complete genotyping
 #' data. If sele.g="p", it will consider that the data is a selective
@@ -48,17 +48,17 @@
 #' @param type character. The population type of the dataset. Include
 #' backcross (type="BC"), advanced intercross population (type="AI"), and
 #' recombinant inbred population (type="RI").
-#' @param D.matrix matrix. The design matrix of QTL effects which is a
-#' g*p matrix, where g is the number of possible QTL genotypes, and p
-#' is the number of effects considered in the MIM model. The design
-#' matrix can be easily generated by the function D.make(). If being NULL,
-#' it Will automatically generate a design matrix with all additive and
-#' dominant effect and without any epistasis effect.
+#' @param D.matrix matrix. The design matrix of QTL effects is a g*p
+#' matrix, where g is the number of possible QTL genotypes, and p is the
+#' number of effects considered in the MIM model. The design matrix can
+#' be easily generated by the function D.make(). If being NULL, it Will
+#' automatically generate a design matrix with all additive and
+#' dominant effects and without any epistasis effect.
 #' @param ng integer. The generation number of the population type. For
 #' example, the BC1 population is type="BC" with ng=1; the AI F3
 #' population is type="AI" with ng=3.
 #' @param cM logical. Specify the unit of marker position. cM=TRUE for
-#' centi-Morgan. Or cM=FALSE for Morgan.
+#' centimorgan. Or cM=FALSE for morgan.
 #' @param scope numeric vector. The search scope of each QTL. In the
 #' MIM process, it will search forward and backward for the corresponding
 #' cM. User can assign a numeric number for every QTL or a numeric vector
@@ -66,11 +66,11 @@
 #' is fixed, and the position of its surrounding positions will not be
 #' searched.
 #' @param speed numeric. The walking speed of the QTL search (in cM).
-#' @param crit numeric. The convergence criterion of EM algorithm.
+#' @param crit numeric. The convergence criterion of the EM algorithm.
 #' The E and M steps will be iterated until a convergence criterion
-#' is satisfied.
-#' @param console logical. To decide whether the process of algorithm will
-#' be shown in the R console or not.
+#' is satisfied. It must be between 0 and 1.
+#' @param console logical. To decide whether the process of the algorithm
+#' will be shown in the R console or not.
 #'
 #' @return
 #' \item{effect}{The estimated effects, log likelihood value, and LRT
@@ -78,7 +78,7 @@
 #' \item{QTL.best}{The positions of the best QTL combination.}
 #' \item{effect.best}{The estimated effects and LRT statistics of the best
 #' QTL combination.}
-#' \item{model}{The model of selective genotyping data in this analyze.}
+#' \item{model}{The model of selective genotyping data in this analysis.}
 #'
 #' @export
 #'
@@ -222,8 +222,8 @@ MIM.points2 <- function(QTL, marker, geno, y, yu = NULL, sele.g = "n", tL = NULL
     scope <- rep(scope[1],nq)
   }
 
-  if(!is.numeric(crit) | length(crit) > 1 | min(crit) < 0){
-    stop("Parameter crit error, please input a positive number.", call. = FALSE)
+  if(!is.numeric(crit) | length(crit) > 1 | min(crit) <= 0 | max(crit) >= 1){
+    stop("Parameter crit error, please input a positive number between 0 and 1.", call. = FALSE)
   }
 
   if(!console[1] %in% c(0,1) | length(console) > 1){console <- TRUE}
